@@ -152,8 +152,6 @@ def get_linux_pass(browser="Chrome"):
 
     if my_pass:
         return my_pass
-    else:
-        return "peanuts"
 
 
 class Chrome:
@@ -175,18 +173,34 @@ class Chrome:
 
         elif sys.platform.startswith('linux'):
             # running Chrome on Linux
-            # chrome linux is encrypted with the key peanuts
-            my_pass = get_linux_pass().encode('utf8')
+            for name in ('Chrome', 'Chromium'):
+                my_pass = get_linux_pass(name)
+                if my_pass is not None:
+                    my_pass = my_pass.encode('utf8')
+                    if name == 'Chromium':
+                        paths = map(os.path.expanduser, [
+                            '~/.config/chromium/Default/Cookies',
+                        ])
+                    else:
+                        paths = map(os.path.expanduser, [
+                            '~/.config/google-chrome/Default/Cookies',
+                            '~/.config/google-chrome-beta/Default/Cookies'
+                        ])
+                    break
+            else:
+                # try default key 'peanuts' with all possible paths (probably won't work)
+                my_pass = 'peanuts'
+                paths = map(os.path.expanduser, [
+                    '~/.config/google-chrome/Default/Cookies',
+                    '~/.config/chromium/Default/Cookies',
+                    '~/.config/google-chrome-beta/Default/Cookies'
+                ])
             iterations = 1
             self.key = PBKDF2(my_pass, self.salt,
                               iterations=iterations).read(self.length)
-            paths = map(os.path.expanduser, [
-                '~/.config/google-chrome/Default/Cookies',
-                '~/.config/chromium/Default/Cookies',
-                '~/.config/google-chrome-beta/Default/Cookies'
-            ])
             cookie_file = cookie_file or next(
                 filter(os.path.exists, paths), None)
+
         elif sys.platform == "win32":
 
             # Read key from file
@@ -218,6 +232,10 @@ class Chrome:
             raise BrowserCookieError(
                 "OS not recognized. Works on Chrome for OSX, Windows, and Linux.")
 
+        # if the cookie_file is None, could not find a Chrome cookie
+        if cookie_file is None:
+            raise BrowserCookieError('Failed to find Chrome cookie')
+        
         # if the type of cookie_file is list, use the first element in the list
         if isinstance(cookie_file, list):
             if not cookie_file:
